==> arduino-esp32-2.0.1.tgz: share/arduino/hardware/espressif/esp32/variants/mpython/pins_arduino.h <==
#ifndef Pins_Arduino_h
#define Pins_Arduino_h

#include <stdint.h>

#define EXTERNAL_NUM_INTERRUPTS 16
#define NUM_DIGITAL_PINS        40
#define NUM_ANALOG_INPUTS       16

#define analogInputToDigitalPin(p)  (((p)<20)?(esp32_adc2gpio[(p)]):-1)
#define digitalPinToInterrupt(p)    (((p)<40)?(p):-1)
#define digitalPinHasPWM(p)         (p < 34)

static const uint8_t TX = 1;
static const uint8_t RX = 3;

static const uint8_t SDA = 23;
static const uint8_t SCL = 22;

static const uint8_t SS    = 5;
static const uint8_t MOSI  = 23;
static const uint8_t MISO  = 19;
static const uint8_t SCK   = 18;

static const uint8_t A0 = 36;
static const uint8_t A3 = 39;
static const uint8_t A4 = 32;
static const uint8_t A5 = 33;
static const uint8_t A6 = 34;
static const uint8_t A7 = 35;
static const uint8_t A10 = 4;
static const uint8_t A11 = 0;
static const uint8_t A12 = 2;
static const uint8_t A13 = 15;
static const uint8_t A14 = 13;
static const uint8_t A15 = 12;
static const uint8_t A16 = 14;
static const uint8_t A17 = 27;
static const uint8_t A18 = 25;
static const uint8_t A19 = 26;

static const uint8_t T0 = 4;
static const uint8_t T1 = 0;
static const uint8_t T2 = 2;
static const uint8_t T3 = 15;
static const uint8_t T4 = 13;
static const uint8_t T5 = 12;
static const uint8_t T6 = 14;
static const uint8_t T7 = 27;
static const uint8_t T8 = 33;
static const uint8_t T9 = 32;

static const uint8_t DAC1 = 25;
static const uint8_t DAC2 = 26;


static const uint8_t P0 = 33;
static const uint8_t P1 = 32;
static const uint8_t P2 = 35;
static const uint8_t P3 = 34;
static const uint8_t P4 = 39;
static const uint8_t P5 = 0;
static const uint8_t P6 = 16;
static const uint8_t P7 = 17;
static const uint8_t P8 = 26;
static const uint8_t P9 = 25;
static const uint8_t P10 = 36;
static const uint8_t P11 = 2;
static const uint8_t P13 = 18;
static const uint8_t P14 = 19;
static const uint8_t P15 = 21;
static const uint8_t P16 = 5;
static const uint8_t P19 = 22;
static const uint8_t P20 = 23;

static const uint8_t P = 27;
static const uint8_t Y = 14;
static const uint8_t T = 12;
static const uint8_t H = 13;
static const uint8_t O = 15;
static const uint8_t N = 4;

static const uint8_t BTN_A = 0;
static const uint8_t BTN_B = 2;
static const uint8_t SOUND = 36;
static const uint8_t LIGHT = 39;
static const uint8_t BUZZER = 16;


#endif /* Pins_Arduino_h */

==> arduino-esp32-2.0.4p4.tgz: share/arduino/hardware/espressif/esp32/variants/mpython/pins_arduino.h <==
#ifndef Pins_Arduino_h
#define Pins_Arduino_h

#include <stdint.h>

#define EXTERNAL_NUM_INTERRUPTS 16
#define NUM_DIGITAL_PINS        40
#define NUM_ANALOG_INPUTS       16

#define analogInputToDigitalPin(p)  (((p)<20)?(analogChannelToDigitalPin(p)):-1)
#define digitalPinToInterrupt(p)    (((p)<40)?(p):-1)
#define digitalPinHasPWM(p)         (p < 34)

static const uint8_t TX = 1;
static const uint8_t RX = 3;

static const uint8_t SDA = 23;
static const uint8_t SCL = 22;

static const uint8_t SS    = 5;
static const uint8_t MOSI  = 23;
static const uint8_t MISO  = 19;
static const uint8_t SCK   = 18;

static const uint8_t A0 = 36;
static const uint8_t A3 = 39;
static const uint8_t A4 = 32;
static const uint8_t A5 = 33;
static const uint8_t A6 = 34;
static const uint8_t A7 = 35;
static const uint8_t A10 = 4;
static const uint8_t A11 = 0;
static const uint8_t A12 = 2;
static const uint8_t A13 = 15;
static const uint8_t A14 = 13;
static const uint8_t A15 = 12;
static const uint8_t A16 = 14;
static const uint8_t A17 = 27;
static const uint8_t A18 = 25;
static const uint8_t A19 = 26;

static const uint8_t T0 = 4;
static const uint8_t T1 = 0;
static const uint8_t T2 = 2;
static const uint8_t T3 = 15;
static const uint8_t T4 = 13;
static const uint8_t T5 = 12;
static const uint8_t T6 = 14;
static const uint8_t T7 = 27;
static const uint8_t T8 = 33;
static const uint8_t T9 = 32;

static const uint8_t DAC1 = 25;
static const uint8_t DAC2 = 26;


static const uint8_t P0 = 33;
static const uint8_t P1 = 32;
static const uint8_t P2 = 35;
static const uint8_t P3 = 34;
static const uint8_t P4 = 39;
static const uint8_t P5 = 0;
static const uint8_t P6 = 16;
static const uint8_t P7 = 17;
static const uint8_t P8 = 26;
static const uint8_t P9 = 25;
static const uint8_t P10 = 36;
static const uint8_t P11 = 2;
static const uint8_t P13 = 18;
static const uint8_t P14 = 19;
static const uint8_t P15 = 21;
static const uint8_t P16 = 5;
static const uint8_t P19 = 22;
static const uint8_t P20 = 23;

static const uint8_t P = 27;
static const uint8_t Y = 14;
static const uint8_t T = 12;
static const uint8_t H = 13;
static const uint8_t O = 15;
static const uint8_t N = 4;

static const uint8_t BTN_A = 0;
static const uint8_t BTN_B = 2;
static const uint8_t SOUND = 36;
static const uint8_t LIGHT = 39;
static const uint8_t BUZZER = 16;


#endif /* Pins_Arduino_h */
